| Title: | Simplify Reporting Many Tables |
|---|---|
| Description: | Simplify reporting many tables by creating tibbles of tables. With 'tabtibble', a tibble of tables is created with captions and automatic printing using knit_print(). |
| Authors: | Bill Denney [aut, cre] (ORCID: <https://orcid.org/0000-0002-5759-428X>) |
| Maintainer: | Bill Denney <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.1.9000 |
| Built: | 2026-05-24 07:22:28 UTC |
| Source: | https://github.com/humanpred/tabtibble |
Print a tab_list
## S3 method for class 'tab_list' knit_print( x, ..., caption, print_fun = NULL, tab_prefix = NULL, tab_suffix = "\n\n" )## S3 method for class 'tab_list' knit_print( x, ..., caption, print_fun = NULL, tab_prefix = NULL, tab_suffix = "\n\n" )
x |
The |
... |
passed to |
caption |
The caption for each table as a character vector |
print_fun |
Override the default printing using |
tab_prefix, tab_suffix
|
Any text to add before/after each figure ( |
Individual tables are printed with the print_tabtibble() S3 generic
function.
x invisibly
Other knitters:
knit_print.tab_tibble()
Print a tab_tibble
## S3 method for class 'tab_tibble' knit_print(x, ...)## S3 method for class 'tab_tibble' knit_print(x, ...)
x |
The |
... |
Passed to subsequent methods |
x invisibly
Other knitters:
knit_print.tab_list()
tab_tibble objectCreate a new tab_tibble object
new_tab_tibble(x) new_tab_list(x)new_tab_tibble(x) new_tab_list(x)
x |
The object to convert |
An object with the desired class
new_tab_list(): Create a new tab_list object
Print a single table from a tablist
print_tabtibble(x, caption, ...) ## Default S3 method: print_tabtibble(x, caption, ...)print_tabtibble(x, caption, ...) ## Default S3 method: print_tabtibble(x, caption, ...)
x |
A table to print |
caption |
The caption for the table |
... |
Passed to |
The result of pander::pander
print_tabtibble(default): Print a single table from a tablist using pander::pander()